/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/




#ifndef ___M_INCLUDE_H___
#define ___M_INCLUDE_H___

#define _open64	open64
#define _lseek64	lseek64
#define _stat64		stat64
#define stat64_t	stat64
#define WAT_DEFAULT_INTERVAL	10

#define CW_ACTIVE	0
#define CW_LAST_INVOKE_INTERVAL 60
#define CW_TH		20
#define CW_PITCH	10
#define CW_INTERVAL	2


#endif

